Module broker

Module broker 

Structs

DHTRouter
This links the DHTRouter module with other modules, so that all messages are correctly translated from one to the other. For this example, it uses the RandomConnections module to communicate with other nodes.

Enums

DHTRouterIn
DHTRouterOut

Type Aliases

BrokerDHTRouter