pub enum DHTRouterIn {
MessageBroadcast(NetworkWrapper),
MessageNeighbour(NodeID, NetworkWrapper),
MessageClosest(U256, NetworkWrapper),
MessageDirect(NodeID, NetworkWrapper),
}Variants
MessageBroadcast(NetworkWrapper)
Sends a message to all nodes connected directly to this node.
MessageNeighbour(NodeID, NetworkWrapper)
Sends the message to a direct neighbour and drops it if the neighbour is not reachable.
MessageClosest(U256, NetworkWrapper)
Routes the message to the closest node representing the ID.
MessageDirect(NodeID, NetworkWrapper)
Routes the message to a specific node. No guarantee can be given as to the delivery of the message.