pub struct DHTRouter {
pub broker: BrokerDHTRouter,
pub stats: Receiver<Stats>,
}Expand description
This links the DHTRouter module with other modules, so that all messages are correctly translated from one to the other. For this example, it uses the RandomConnections module to communicate with other nodes.
Fields
broker: BrokerDHTRouterstats: Receiver<Stats>Implementations
Sourceimpl DHTRouter
impl DHTRouter
pub async fn start( config: Config, timer: BrokerTimer, router: BrokerRouter, ) -> Result<Self>