DHTStorage

Struct DHTStorage 

pub struct DHTStorage {
    pub broker: Broker<DHTStorageIn, DHTStorageOut>,
    pub stats: Receiver<Stats>,
    /* private fields */
}
This links the DHTStorage module with other modules, so that all messages are correctly translated from one to the other. For this example, it uses the RandomConnections module to communicate with other nodes.

The DHTStorage holds the [Translate] and offers convenience methods to interact with [Translate] and [DHTStorageMessage].

Fields

broker: Broker<DHTStorageIn, DHTStorageOut>

Represents the underlying broker.

stats: Receiver<Stats>

Implementations

Source

impl DHTStorage

pub async fn start( ds: Box<dyn DataStorage + Send>, config: DHTConfig, timer: BrokerTimer, dht_router: BrokerDHTRouter, ) -> Result<Self>

pub fn store_flo(&mut self, flo: Flo) -> Result<()>

pub fn propagate(&mut self) -> Result<()>

pub async fn get_realm_ids(&mut self) -> Result<Vec<RealmID>>

pub async fn get_flo<T: Serialize + DeserializeOwned + Clone>( &mut self, id: &GlobalID, ) -> Result<FloWrapper<T>>

pub async fn get_flo_timeout<T: Serialize + DeserializeOwned + Clone>( &mut self, id: &GlobalID, timeout: u64, ) -> Result<FloWrapper<T>>

pub async fn get_flos(&mut self) -> Result<Vec<Flo>>

pub async fn get_cuckoos(&mut self, id: &GlobalID) -> Result<Vec<FloID>>

pub fn sync(&mut self) -> Result<()>

pub fn convert<'life0, 'life1, 'life_self, 'async_recursion>( &'life_self mut self, cl: &'life0 ConditionLink, rid: &'life1 RealmID, ) -> Pin<Box<dyn Future<Output = Condition> + 'async_recursion>>
where 'life0: 'async_recursion, 'life1: 'async_recursion, 'life_self: 'async_recursion,

pub async fn start_sign_cond<T: Serialize + DeserializeOwned + Clone>( &mut self, fw: &FloWrapper<T>, cl: &ConditionLink, ) -> Result<UpdateCondSign>

pub async fn get_realm_view(&mut self, rid: RealmID) -> Result<RealmView>