pub enum WSSignalMessageFromNode {
Announce(MessageAnnounce),
ListIDsRequest,
PeerSetup(PeerInfo),
NodeStats(Vec<NodeStat>),
}Expand description
A message coming from a node
Variants
Announce(MessageAnnounce)
The reply to a WSSignalMessageToNode::Challenge message, containing information about the
node, as well as a signature on the random 256 bit number being sent in the challenge.
ListIDsRequest
Request an updated list of the currently connected nodes
PeerSetup(PeerInfo)
Connection information for setting up a WebRTC connection
NodeStats(Vec<NodeStat>)
Some statistics about its connections from the remote node