pub struct SignalServer { /* private fields */ }Expand description
This implements a signalling server. It can be used for tests, in the cli implementation, and will also be used later directly in the network struct to allow for direct node-node setups.
It handles the setup phase where the nodes authenticate themselves to the server, and passes PeerInfo messages between nodes. It also handles statistics by forwarding NodeStats to a listener.
Implementations
Sourceimpl SignalServer
impl SignalServer
Sourcepub async fn start(
ws_server: BrokerWSServer,
config: SignalConfig,
) -> Result<BrokerSignal>
pub async fn start( ws_server: BrokerWSServer, config: SignalConfig, ) -> Result<BrokerSignal>
Creates a new SignalServer.
ttl_minutes is the minimum time an idle node will be
kept in the list.
pub async fn new(config: SignalConfig) -> Result<BrokerSignal>