Module nodeconfig

Module nodeconfig 

Configuration structures that define a node, including old versions for migrations. Also configuration for starting a new node.

All node-configurations can be serialized with serde and offer nice hex based serializations when using text-based serializations like yaml or json.

Structs

ModulesV2
NodeConfig
NodeConfig is stored on the node itself and contains the private key.
NodeConfigV2
NodeConfig is stored on the node itself and contains the private key.
NodeInfo
NodeInfo is the public information of the node.
NodeInfoV3
NodeInfo is the public information of the node.

Enums

ConfigError
Errors to be returned when setting up a new config