pub struct NodeInfo {
pub name: String,
pub client: String,
pub pubkey: Vec<u8>,
pub modules: Modules,
/* private fields */
}Expand description
NodeInfo is the public information of the node.
Fields
name: StringName of the node, up to 256 bytes
client: StringWhat client this node runs on - “Node” or the navigator id
pubkey: Vec<u8>the public key of the node
modules: ModulesImplementations
Sourceimpl NodeInfo
impl NodeInfo
pub fn new_from_id(id: NodeID) -> NodeInfo
pub fn new_from_id_kp(id: NodeID, pubkey: PublicKey) -> NodeInfo
Sourcepub fn verify(&self, msg: &[u8], sig_bytes: &[u8]) -> bool
pub fn verify(&self, msg: &[u8], sig_bytes: &[u8]) -> bool
Verifies a signature with the public key of this NodeInfo
Sourcepub fn decode(data: &str) -> Result<Self, ConfigError>
pub fn decode(data: &str) -> Result<Self, ConfigError>
Decodes a given string as yaml and returns the corresponding NodeInfo.