Module broker

Module broker 

Structs

Multi
A structure containing one or more states which are automatically updated.

Enums

MultiIn
The messages this broker takes as input.
MultiOut
The messages this broker outputs.

Type Aliases

BrokerMulti
For other brokers who want to connect to this broker.