pub struct Multi {
pub state: Receiver<Intern>,
pub broker: BrokerMulti,
}Expand description
A structure containing one or more states which are automatically updated.
Fields
state: Receiver<Intern>The new state of the template.
broker: BrokerMultiA broker to be used in other brokers.
Implementations
Sourceimpl Multi
impl Multi
Sourcepub async fn start(timer: BrokerTimer, network: BrokerNetwork) -> Result<Multi>
pub async fn start(timer: BrokerTimer, network: BrokerNetwork) -> Result<Multi>
Returns a Multi and starts the broker. It uses a tap to update the state field of the structure.
Sourcepub async fn broker(
timer: BrokerTimer,
network: BrokerNetwork,
) -> Result<BrokerMulti>
pub async fn broker( timer: BrokerTimer, network: BrokerNetwork, ) -> Result<BrokerMulti>
Just returns the broker for the multi template.