Configuration structures that define a node, including old versions for migrations. Also configuration for starting a new node.
All node-configurations can be serialized with serde and offer nice hex
based serializations when using text-based serializations like yaml or json.
Structs
- Modules
V2 - Node
Config - NodeConfig is stored on the node itself and contains the private key.
- Node
Config V2 - NodeConfig is stored on the node itself and contains the private key.
- Node
Info - NodeInfo is the public information of the node.
- Node
Info V3 - NodeInfo is the public information of the node.
Enums
- Config
Error - Errors to be returned when setting up a new config